@@ -14,8 +14,9 @@
 
 """Base class module for nRF Connect SDK platform device."""
 import os
-from typing import Dict, Tuple, NoReturn
+from typing import Dict, Tuple
 
+from gazoo_device import custom_types
 from gazoo_device import decorators
 from gazoo_device import errors
 from gazoo_device import gdm_logger
@@ -53,29 +54,11 @@ class NRFConnectSDKDevice(auxiliary_device.AuxiliaryDevice):
     return persistent_dict, {}
 
   @classmethod
-  def is_connected(cls, device_config: Dict[str, str]) -> bool:
-    """Checks whether or not the device is connected to the host.
-
-    Args:
-      device_config: Contains "persistent" dict.
-
-    Returns:
-      Whether or not the serial port is connected.
-    """
+  def is_connected(cls,
+                   device_config: custom_types.ManagerDeviceConfigDict) -> bool:
+    """Returns True if the device is connected to the host."""
     return os.path.exists(device_config["persistent"]["console_port_name"])
 
-  @decorators.LogDecorator(logger)
-  def recover(self, error: errors.CheckDeviceReadyError) -> NoReturn:
-    """Recovery method to overwrite the abstract base class.
-
-    Args:
-      error: Checks device ready error.
-
-    Raises:
-      CheckDeviceReadyError: Currently no recovery mechanism is implemented.
-    """
-    raise error
-
   @decorators.PersistentProperty
   def os(self) -> str:
     return "Zephyr RTOS"
