@@ -27,6 +27,7 @@ SEARCHWINDOWSIZE = 2000  # Default size of search window for switchboard methods
 
 DEFAULT_LOG_DIRECTORY = os.path.join(INSTALL_DIRECTORY, "log")
 CONFIG_DIRECTORY = os.path.join(INSTALL_DIRECTORY, "conf")
+DATA_DIRECTORY = os.path.join(INSTALL_DIRECTORY, "data")
 BACKUP_PARENT_DIRECTORY = os.path.join(CONFIG_DIRECTORY, "backup")
 BOTO_DIRECTORY = os.path.join(INSTALL_DIRECTORY, "botos")
 KEYS_DIRECTORY = os.path.join(INSTALL_DIRECTORY, "keys")
@@ -35,7 +36,7 @@ DETOK_DIRECTORY = os.path.join(INSTALL_DIRECTORY, "detok")
 VIRTUAL_ENV_DIRECTORY = os.path.join(INSTALL_DIRECTORY, "virtual_env")
 
 REQUIRED_FOLDERS = [
-    INSTALL_DIRECTORY, CONFIG_DIRECTORY, DEFAULT_LOG_DIRECTORY,
+    INSTALL_DIRECTORY, CONFIG_DIRECTORY, DATA_DIRECTORY, DEFAULT_LOG_DIRECTORY,
     BACKUP_PARENT_DIRECTORY, BOTO_DIRECTORY, KEYS_DIRECTORY, DETOK_DIRECTORY
 ]
 
